<template>
  <el-bus-crud v-bind="tableConfig" />
</template>

<script>
import { getGoodsCategoryListConfig } from '@/utils/form-item-config'

export default {
  data() {
    return {
      tableConfig: {
        url: 'flower/api/flower/markup/spcg/list',
        newUrl: 'flower/api/flower/markup/spcg/list/save',
        editUrl: 'flower/api/flower/markup/spcg/list/save',
        onDelete: (row) => {
          return this.$elBusHttp.request(
            'flower/api/flower/markup/spcg/list/delete',
            {
              params: {
                categoryId: row.categoryId,
              },
            }
          )
        },
        operationAttrs: {
          width: '140px',
          fixed: 'right',
        },
        dialogAttrs: {
          width: '70%',
        },
        columns: [
          { label: '分类名称', prop: 'name', minWidth: 100, fixed: 'left' },
          {
            label: '分类图片',
            formatter: (row) => (
              <el-bus-image style="width:50px;height:50px" src={row.imageUrl} />
            ),
            minWidth: 100,
          },
          { label: '上级分类', prop: 'parentName', minWidth: 120 },
          { label: '分类颜色', prop: 'color', minWidth: 100 },
          { label: '分类规格', prop: 'unit', minWidth: 120 },
          { label: 'A级加价(元)', prop: 'levelA', minWidth: 120 },
          { label: 'B级加价(元)', prop: 'levelB', minWidth: 120 },
          { label: 'C级加价(元)', prop: 'levelC', minWidth: 120 },
          { label: 'D级加价(元)', prop: 'levelD', minWidth: 120 },
          { label: 'E级加价(元)', prop: 'levelE', minWidth: 120 },
          { label: 'O级加价(元)', prop: 'levelO', minWidth: 120 },
        ],
        searchForm: [
          {
            type: 'row',
            items: [
              {
                ...getGoodsCategoryListConfig(true),
              },
            ],
          },
        ],
        form: [
          {
            ...getGoodsCategoryListConfig(true),
            rules: { required: true, message: '请选择商品分类' },
            str: true,
            strKey: 'name',
            readonly: (row, item, mode) => {
              return mode === 'edit'
            },
          },
          {
            type: 'row',
            items: [
              {
                label: 'A级：',
                id: 'levelA',
                type: 'input-number',
                el: { precision: 2, min: 0 },
                rules: {
                  required: true,
                  message: '请输入A级加价',
                  trigger: 'blur',
                },
                unit: '元',
              },
              {
                label: 'B级：',
                id: 'levelB',
                type: 'input-number',
                el: { precision: 2, min: 0 },
                rules: {
                  required: true,
                  message: '请输入B级加价',
                  trigger: 'blur',
                },
                unit: '元',
              },
              {
                label: 'C级：',
                id: 'levelC',
                type: 'input-number',
                el: { precision: 2, min: 0 },
                rules: {
                  required: true,
                  message: '请输入C级加价',
                  trigger: 'blur',
                },
                unit: '元',
              },
              {
                label: 'D级：',
                id: 'levelD',
                type: 'input-number',
                el: { precision: 2, min: 0 },
                rules: {
                  required: true,
                  message: '请输入D级加价',
                  trigger: 'blur',
                },
                unit: '元',
              },
              {
                label: 'E级：',
                id: 'levelE',
                type: 'input-number',
                el: { precision: 2, min: 0 },
                rules: {
                  required: true,
                  message: '请输入E级加价',
                  trigger: 'blur',
                },
                unit: '元',
              },
              {
                label: 'O级：',
                id: 'levelO',
                type: 'input-number',
                el: { precision: 2, min: 0 },
                rules: {
                  required: true,
                  message: '请输入O级加价',
                  trigger: 'blur',
                },
                unit: '元',
              },
            ],
          },
        ],
      },
    }
  },
  head() {
    return {
      title: '分类加价',
    }
  },
}
</script>

<style lang="scss" scoped></style>
